@@ -2987,18 +2987,19 @@ delete_placeholder (GtkWidget * placeholder)
   child_name = gb_widget_get_child_name (placeholder);
   if (child_name)
     {
-      if (!strcmp (child_name, "CList:title")
-	  || !strcmp (child_name, "CTree:title")
-#ifdef USE_GNOME	  
-	  || !strcmp (child_name, "GnomeDock:contents")
-#endif
-	  )
+      if (!strcmp (child_name, GladeChildCListTitle))
 	{
 	  MSG1 ("Not deleting special widget: %s\n", child_name);
 	  return;
 	}
     }
 
+  /* SPECIAL CODE: Don't allow placeholder in BonoboDock to be deleted. */
+#ifdef USE_GNOME	  
+  if (BONOBO_IS_DOCK (parent))
+    return;
+#endif
+
   /* Remove widget from the selection */
   editor_clear_selection (NULL);
 
@@ -3236,29 +3237,34 @@ editor_delete_widget (GtkWidget * widget)
   if (GNOME_IS_DRUID_PAGE (widget))
     {
       gint num_pages;
-      GList *elem;
+      GList *children, *elem;
       GnomeDruidPage *new_current_page;
 
       g_return_if_fail (GNOME_IS_DRUID (parent));
-#ifdef FIXME
-      num_pages = g_list_length (GNOME_DRUID (parent)->children);
+
+      children = gtk_container_get_children (GTK_CONTAINER (parent));
+      num_pages = g_list_length (children);
       if (num_pages == 1)
 	{
 	  editor_delete_widget (parent);
-	  return;
+	}
+      else
+	{
+	  elem = g_list_find (children, widget);
+	  g_return_if_fail (elem != NULL);
+
+	  if (elem->next)
+	    new_current_page = elem->next->data;
+	  else
+	    new_current_page = elem->prev->data;
+
+	  gnome_druid_set_page (GNOME_DRUID (parent), new_current_page);
+
+	  gtk_widget_destroy (widget);
 	}
 
-      elem = g_list_find (GNOME_DRUID (parent)->children, widget);
-      g_return_if_fail (elem != NULL);
+      g_list_free (children);
 
-      if (elem->next)
-	new_current_page = elem->next->data;
-      else
-	new_current_page = elem->prev->data;
-
-      gnome_druid_set_page (GNOME_DRUID (parent), new_current_page);
-#endif
-      gtk_widget_destroy (widget);
       return;
     }
 #endif
