@@ -72,10 +72,10 @@ static void glade_clipboard_on_project_destroy (GladeProject *project,
 #define GLADE_PASTE_BUFFER_INCREMENT	1024
 
 
-guint
+GType
 glade_clipboard_get_type (void)
 {
-  static guint glade_clipboard_type = 0;
+  static GType glade_clipboard_type = 0;
 
   if (!glade_clipboard_type)
     {
