@@ -79,10 +79,10 @@ static void glade_project_options_ok (GtkWidget *widget,
 static gchar* get_entry_text (GtkWidget *entry);
 static gboolean glade_project_options_check_valid	(GladeProjectOptions *options);
 
-guint
+GType
 glade_project_options_get_type (void)
 {
-  static guint glade_project_options_type = 0;
+  static GType glade_project_options_type = 0;
 
   if (!glade_project_options_type)
     {
