@@ -1160,7 +1160,7 @@ source_write_gtk_makefile_am (GbWidgetWriteSourceData * data)
   fprintf (fp,
 	   "INCLUDES = \\\n"
 	   "\t-DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n"
-	   "\t-DPACKAGE_LOCALE_DIR=\\\"\"$(datadir)/locale\"\\\" \\\n"
+	   "\t-DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n"
 	   "\t@PACKAGE_CFLAGS@\n"
 	   "\n");
 
@@ -1501,7 +1501,7 @@ source_write_gnome_makefile_am (GbWidgetWriteSourceData * data)
   fprintf (fp,
 	   "INCLUDES = \\\n"
 	   "\t-DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n"
-	   "\t-DPACKAGE_LOCALE_DIR=\\\"\"$(datadir)/locale\"\\\" \\\n"
+	   "\t-DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n"
 	   "\t@PACKAGE_CFLAGS@\n"
 	   "\n");
 
